..
    This file is part of Invenio.
    Copyright (C) 2015-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


=====================
 Invenio-Communities
=====================

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-communities.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-communities

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-communities.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-communities

.. image:: https://img.shields.io/pypi/v/invenio-communities.svg
        :target: https://pypi.org/pypi/invenio-communities


Invenio module that adds support for communities.

*This is an experimental developer preview release.*

* Free software: MIT license
* Documentation: https://invenio-communities.readthedocs.io/
